Crate moving_least_squares

Crate moving_least_squares 

Image deformation using moving least squares.

Functions

deform_affine
Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.
deform_rigid
Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.
deform_similarity
Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.