Image deformation using moving least squares.
Functions
- deform_
affine - Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.
- deform_
rigid - Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.
- deform_
similarity - Move a given point from its original position to its new position according to the deformation that transforms the original control points into their displaced locations.